@@ -1,5 +1,6 @@
 import os
 import sys
+import requests
 import tarfile
 import tempfile
 import backstage
@@ -11,6 +12,7 @@ class Act():
         self.venue = venue
         self.actname = actname
         self.acthome = os.path.join(self.venue.VENUE_ROOT, 'acts', actname)
+        self.uwsgi_ip = None
         self.uwsgi_port = None
         self.uwsgifile = os.path.join(self.acthome, 'uwsgi.ini')
         if not os.path.exists(self.acthome):
@@ -64,9 +66,26 @@ class Act():
 
     def get_uwsgi_port(self):
         from backstage.utils import uwsgi_portsniffer
-        p = uwsgi_portsniffer.portsniffer(self.uwsgi_log)
-        self.uwsgi_port = p
-        print str(p)
+        ip, port = uwsgi_portsniffer.portsniffer(self.uwsgi_log)
+        print 'ip:',ip
+        if port is None:
+            print "No port.  Try self.uwsgi_linker(linkmode='link')"
+            return
+        uwsgi_uri = 'http://%s:%s' % (ip, port)
+        try:
+            h = requests.head(uwsgi_uri)
+            if h.status_code == 200:
+                self.uwsgi_ip = ip
+                self.uwsgi_port = port
+                print str(ip), str(port)
+            else:
+                self.uwsgi_ip = None
+                self.uwsgi_port = None
+        except:
+            raise
+            self.uwsgi_ip = None
+            self.uwsgi_port = None
+            print 'None'
         return
 
 
